<?xml version="1.0" ?><!DOCTYPE TS><TS language="bn" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>select-area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="986"/>
        <location filename="../mainwindow.cpp" line="988"/>
        <location filename="../mainwindow.cpp" line="1246"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="1262"/>
        <location filename="../mainwindow.cpp" line="1265"/>
        <location filename="../mainwindow.cpp" line="1302"/>
        <location filename="../mainwindow.cpp" line="1305"/>
        <location filename="../mainwindow.cpp" line="1337"/>
        <location filename="../mainwindow.cpp" line="1340"/>
        <source>DeepinScreenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1004"/>
        <location filename="../mainwindow.cpp" line="1366"/>
        <source>View</source>
        <translation>দেখুন</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1018"/>
        <location filename="../mainwindow.cpp" line="1386"/>
        <source>Picture has been saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1270"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1360"/>
        <source>Save failed. Please save it in your home directory.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Picture has been saved to clipboard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="40"/>
        <source>Rectangle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="48"/>
        <source>Ellipse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="56"/>
        <source>Arrow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="64"/>
        <source>Pencil</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="72"/>
        <source>Text</source>
        <translation>টেক্সট</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="80"/>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="96"/>
        <source>Save</source>
        <translation>সংরক্ষণ করুন</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Save to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="100"/>
        <source>Autosave</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="101"/>
        <source>Save to specified folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="102"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="103"/>
        <source>Autosave and copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="124"/>
        <source>Exit</source>
        <translation>বের হয়ে যান</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="78"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Start/Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Save</source>
        <translation>সংরক্ষণ করুন</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Painting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="32"/>
        <source>Size Adjustment</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Quick start</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Full screenshot</source>
        <translation>সম্পূর্ণ স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Delay screenshot</source>
        <translation>বিলম্ব স্ক্রিনশট</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Exit</source>
        <translation>বের হয়ে যান</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="42"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="45"/>
        <source>Rectangle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="46"/>
        <source>Ellipse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="47"/>
        <source>Arrow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="48"/>
        <source>Pencil</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="49"/>
        <source>Text</source>
        <translation>টেক্সট</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="50"/>
        <source>Color</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="53"/>
        <source>Increase height up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="54"/>
        <source>Increase height down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="55"/>
        <source>Increase width left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="56"/>
        <source>Increase width right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="57"/>
        <source>Decrease height up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="58"/>
        <source>Decrease height down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="59"/>
        <source>Decrease width left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="60"/>
        <source>Decrease width right</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="397"/>
        <source>Save to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="403"/>
        <source>Autosave</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="409"/>
        <source>Save to specified folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="415"/>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="420"/>
        <source>Autosave and copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="425"/>
        <source>Low</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="439"/>
        <source>High</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>